@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -10,10 +12,12 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/bin',
- 'BINLIBDEST': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9',
- 'BLDLIBRARY': '-L. -lpython3.9',
- 'BLDSHARED': 'gcc -pthread -shared -m64 -m64',
+ 'BINDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/bin',
+ 'BINLIBDEST': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10',
+ 'BLDSHARED': 'gcc -pthread -shared '
+              '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+              '-m64 -m64',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
@@ -32,31 +36,36 @@ build_time_vars = {'ABIFLAGS': '',
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-DNDEBUG -m64',
- 'CONFIGURE_LDFLAGS': '-m64',
+ 'CONFIGURE_CPPFLAGS': '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+                       '-DNDEBUG -m64',
+ 'CONFIGURE_LDFLAGS': '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+                      '-m64',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit' "
+ 'CONFIG_ARGS': "'--prefix=/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit' "
                 "'--enable-shared' '--with-ensurepip=install' "
-                "'--with-openssl=/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit' "
-                "'CC=gcc' 'CFLAGS=-O1 -g -m64 -fno-omit-frame-pointer' "
-                "'LDFLAGS=-m64' 'CPPFLAGS=-DNDEBUG -m64' "
-                "'PKG_CONFIG_PATH=/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib64/pkgconfig:/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib/pkgconfig:/opt/rh/python27/root/usr/lib64/pkgconfig'",
- 'CONFINCLUDEDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include',
- 'CONFINCLUDEPY': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include/python3.9',
+                "'--with-openssl=/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit' "
+                "'CPPFLAGS=-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include "
+                "-DNDEBUG -m64' "
+                "'LDFLAGS=-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib "
+                "-m64' 'CC=gcc' 'CFLAGS=-O1 -g -m64 -fno-omit-frame-pointer'",
+ 'CONFINCLUDEDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include',
+ 'CONFINCLUDEPY': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5/coverage.info',
- 'COVERAGE_REPORT': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5/lcov-report',
+ 'COVERAGE_INFO': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0/coverage.info',
+ 'COVERAGE_REPORT': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -DNDEBUG -m64 -DNDEBUG -m64',
+ 'CPPFLAGS': '-I. -I./Include '
+             '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+             '-DNDEBUG -m64 -DNDEBUG -m64',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit '
-             '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib '
-             '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9 '
-             '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9/lib-dynload',
- 'DESTLIB': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9',
+ 'DESTDIRS': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit '
+             '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib '
+             '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10 '
+             '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -78,11 +87,12 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'install',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-39-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-310-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -120,6 +130,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -172,6 +183,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 0,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -313,6 +325,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -405,6 +418,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -413,7 +427,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 0,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -440,6 +453,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -500,6 +514,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -511,46 +526,49 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include '
-                   '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include '
-                   '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include/python3.9 '
-                   '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include/python3.9',
- 'INCLUDEDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include',
- 'INCLUDEPY': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/include/python3.9',
+ 'INCLDIRSTOMAKE': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include '
+                   '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include '
+                   '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include/python3.10 '
+                   '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include/python3.10',
+ 'INCLUDEDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include',
+ 'INCLUDEPY': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.9.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-m64 -m64',
+ 'LDFLAGS': '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+            '-m64 -m64',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.9.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -m64 -m64',
- 'LDVERSION': '3.9',
+ 'LDSHARED': 'gcc -pthread -shared '
+             '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+             '-m64 -m64',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9',
- 'LIBDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib64/libffi-3.0.5/include',
+ 'LIBDEST': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10',
+ 'LIBDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib',
+ 'LIBFFI_INCLUDEDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/pkgconfig',
- 'LIBPL': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9/config-3.9-x86_64-linux-gnu',
+ 'LIBPC': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/pkgconfig',
+ 'LIBPL': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10/config-3.10-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lrt -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
@@ -562,18 +580,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib/python3.9',
+ 'MACHDESTLIB': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/share/man',
+ 'MANDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '_lzma  _gdbm  _dbm  _tkinter',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -586,17 +604,18 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/include',
- 'OPENSSL_LDFLAGS': '-L/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib',
+ 'OPENSSL_INCLUDES': '-I/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit/include',
+ 'OPENSSL_LDFLAGS': '-L/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -606,8 +625,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
@@ -615,7 +633,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -628,6 +646,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
@@ -638,7 +657,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -DNDEBUG -m64 -DNDEBUG -m64 -fPIC '
+                             '-I./Include '
+                             '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+                             '-DNDEBUG -m64 -DNDEBUG -m64 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall -O1 -g -m64 '
               '-fno-omit-frame-pointer -O1 -g -m64 -fno-omit-frame-pointer',
@@ -652,12 +673,18 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fno-omit-frame-pointer -std=c99 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -DNDEBUG -m64 '
-                   '-DNDEBUG -m64 -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-m64 -m64',
- 'PY_CPPFLAGS': '-I. -I./Include -DNDEBUG -m64 -DNDEBUG -m64',
+                   '-I./Include/internal -I. -I./Include '
+                   '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+                   '-DNDEBUG -m64 -DNDEBUG -m64 -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+                    '-m64 -m64',
+ 'PY_CPPFLAGS': '-I. -I./Include '
+                '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+                '-DNDEBUG -m64 -DNDEBUG -m64',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-m64 -m64',
+ 'PY_LDFLAGS': '-L/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/lib '
+               '-m64 -m64',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
@@ -667,7 +694,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -DNDEBUG -m64 -DNDEBUG -m64 -fPIC',
+                        '-I./Include '
+                        '-I/var/lib/pb2/sb_1-6516999-1648244869.46/libffi-3.3-static-linux-glibc2.12-64bit/include '
+                        '-DNDEBUG -m64 -DNDEBUG -m64 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -676,8 +705,8 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib',
- 'SCRIPTDIR': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0:/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit/lib',
+ 'SCRIPTDIR': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
@@ -704,9 +733,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-310-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -718,35 +748,39 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0:/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit/lib '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638918926.18/openssl-1.1.1l-linux-glibc2.12-64bit/lib '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0:/var/lib/pb2/sb_1-6516999-1648244869.46/openssl-1.1.1n-linux-glibc2.12-64bit/lib '
                './python ./Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
  'TIMEMODULE_LIB': 'rt',
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5',
- 'abs_srcdir': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-export-1444150/Python-3.9.5',
- 'datarootdir': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit/share',
- 'exec_prefix': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit',
- 'prefix': '/var/lib/pb2/sb_1-5451091-1638918926.18/Python-3.9.5-shell-linux-glibc2.12-64bit',
+ 'abs_builddir': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0',
+ 'abs_srcdir': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-export-1726483/Python-3.10.0',
+ 'datarootdir': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit/share',
+ 'exec_prefix': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit',
+ 'prefix': '/var/lib/pb2/sb_1-6516999-1648244869.46/Python-3.10.0-shell-linux-glibc2.12-64bit',
  'srcdir': '.'}
