@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -29,6 +29,10 @@ class TargetDetectorRecipe(object):
     #: This constant has a value of "IAAS_CONFIGURATION_DETECTOR"
     DETECTOR_IAAS_CONFIGURATION_DETECTOR = "IAAS_CONFIGURATION_DETECTOR"
 
+    #: A constant which can be used with the detector property of a TargetDetectorRecipe.
+    #: This constant has a value of "IAAS_THREAT_DETECTOR"
+    DETECTOR_IAAS_THREAT_DETECTOR = "IAAS_THREAT_DETECTOR"
+
     #: A constant which can be used with the lifecycle_state property of a TargetDetectorRecipe.
     #: This constant has a value of "CREATING"
     LIFECYCLE_STATE_CREATING = "CREATING"
@@ -90,7 +94,7 @@ class TargetDetectorRecipe(object):
 
         :param detector:
             The value to assign to the detector property of this TargetDetectorRecipe.
-            Allowed values for this property are: "IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR", "IAAS_THREAT_DETECTOR", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type detector: str
 
@@ -116,6 +120,10 @@ class TargetDetectorRecipe(object):
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type lifecycle_state: str
 
+        :param source_data_retention:
+            The value to assign to the source_data_retention property of this TargetDetectorRecipe.
+        :type source_data_retention: int
+
         """
         self.swagger_types = {
             'id': 'str',
@@ -129,7 +137,8 @@ class TargetDetectorRecipe(object):
             'effective_detector_rules': 'list[TargetDetectorRecipeDetectorRule]',
             'time_created': 'datetime',
             'time_updated': 'datetime',
-            'lifecycle_state': 'str'
+            'lifecycle_state': 'str',
+            'source_data_retention': 'int'
         }
 
         self.attribute_map = {
@@ -144,7 +153,8 @@ class TargetDetectorRecipe(object):
             'effective_detector_rules': 'effectiveDetectorRules',
             'time_created': 'timeCreated',
             'time_updated': 'timeUpdated',
-            'lifecycle_state': 'lifecycleState'
+            'lifecycle_state': 'lifecycleState',
+            'source_data_retention': 'sourceDataRetention'
         }
 
         self._id = None
@@ -159,6 +169,7 @@ class TargetDetectorRecipe(object):
         self._time_created = None
         self._time_updated = None
         self._lifecycle_state = None
+        self._source_data_retention = None
 
     @property
     def id(self):
@@ -188,7 +199,7 @@ class TargetDetectorRecipe(object):
     def display_name(self):
         """
         **[Required]** Gets the display_name of this TargetDetectorRecipe.
-        DisplayName of detector recipe
+        Display name of detector recipe.
 
 
         :return: The display_name of this TargetDetectorRecipe.
@@ -200,7 +211,7 @@ class TargetDetectorRecipe(object):
     def display_name(self, display_name):
         """
         Sets the display_name of this TargetDetectorRecipe.
-        DisplayName of detector recipe
+        Display name of detector recipe.
 
 
         :param display_name: The display_name of this TargetDetectorRecipe.
@@ -212,7 +223,7 @@ class TargetDetectorRecipe(object):
     def description(self):
         """
         Gets the description of this TargetDetectorRecipe.
-        Detector recipe description
+        Detector recipe description.
 
 
         :return: The description of this TargetDetectorRecipe.
@@ -224,7 +235,7 @@ class TargetDetectorRecipe(object):
     def description(self, description):
         """
         Sets the description of this TargetDetectorRecipe.
-        Detector recipe description
+        Detector recipe description.
 
 
         :param description: The description of this TargetDetectorRecipe.
@@ -316,7 +327,7 @@ class TargetDetectorRecipe(object):
         **[Required]** Gets the detector of this TargetDetectorRecipe.
         Type of detector
 
-        Allowed values for this property are: "IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR", "IAAS_THREAT_DETECTOR", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -335,7 +346,7 @@ class TargetDetectorRecipe(object):
         :param detector: The detector of this TargetDetectorRecipe.
         :type: str
         """
-        allowed_values = ["IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR"]
+        allowed_values = ["IAAS_ACTIVITY_DETECTOR", "IAAS_CONFIGURATION_DETECTOR", "IAAS_THREAT_DETECTOR"]
         if not value_allowed_none_or_none_sentinel(detector, allowed_values):
             detector = 'UNKNOWN_ENUM_VALUE'
         self._detector = detector
@@ -466,6 +477,30 @@ class TargetDetectorRecipe(object):
             lifecycle_state = 'UNKNOWN_ENUM_VALUE'
         self._lifecycle_state = lifecycle_state
 
+    @property
+    def source_data_retention(self):
+        """
+        Gets the source_data_retention of this TargetDetectorRecipe.
+        The number of days for which source data is retained
+
+
+        :return: The source_data_retention of this TargetDetectorRecipe.
+        :rtype: int
+        """
+        return self._source_data_retention
+
+    @source_data_retention.setter
+    def source_data_retention(self, source_data_retention):
+        """
+        Sets the source_data_retention of this TargetDetectorRecipe.
+        The number of days for which source data is retained
+
+
+        :param source_data_retention: The source_data_retention of this TargetDetectorRecipe.
+        :type: int
+        """
+        self._source_data_retention = source_data_retention
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
