@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -70,6 +70,18 @@ class Cluster(object):
             The value to assign to the kms_key_id property of this Cluster.
         :type kms_key_id: str
 
+        :param freeform_tags:
+            The value to assign to the freeform_tags property of this Cluster.
+        :type freeform_tags: dict(str, str)
+
+        :param defined_tags:
+            The value to assign to the defined_tags property of this Cluster.
+        :type defined_tags: dict(str, dict(str, object))
+
+        :param system_tags:
+            The value to assign to the system_tags property of this Cluster.
+        :type system_tags: dict(str, dict(str, object))
+
         :param options:
             The value to assign to the options property of this Cluster.
         :type options: oci.container_engine.models.ClusterCreateOptions
@@ -109,6 +121,9 @@ class Cluster(object):
             'vcn_id': 'str',
             'kubernetes_version': 'str',
             'kms_key_id': 'str',
+            'freeform_tags': 'dict(str, str)',
+            'defined_tags': 'dict(str, dict(str, object))',
+            'system_tags': 'dict(str, dict(str, object))',
             'options': 'ClusterCreateOptions',
             'metadata': 'ClusterMetadata',
             'lifecycle_state': 'str',
@@ -126,6 +141,9 @@ class Cluster(object):
             'vcn_id': 'vcnId',
             'kubernetes_version': 'kubernetesVersion',
             'kms_key_id': 'kmsKeyId',
+            'freeform_tags': 'freeformTags',
+            'defined_tags': 'definedTags',
+            'system_tags': 'systemTags',
             'options': 'options',
             'metadata': 'metadata',
             'lifecycle_state': 'lifecycleState',
@@ -142,6 +160,9 @@ class Cluster(object):
         self._vcn_id = None
         self._kubernetes_version = None
         self._kms_key_id = None
+        self._freeform_tags = None
+        self._defined_tags = None
+        self._system_tags = None
         self._options = None
         self._metadata = None
         self._lifecycle_state = None
@@ -318,6 +339,96 @@ class Cluster(object):
         """
         self._kms_key_id = kms_key_id
 
+    @property
+    def freeform_tags(self):
+        """
+        Gets the freeform_tags of this Cluster.
+        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
+        For more information, see `Resource Tags`__.
+        Example: `{\"Department\": \"Finance\"}`
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm
+
+
+        :return: The freeform_tags of this Cluster.
+        :rtype: dict(str, str)
+        """
+        return self._freeform_tags
+
+    @freeform_tags.setter
+    def freeform_tags(self, freeform_tags):
+        """
+        Sets the freeform_tags of this Cluster.
+        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
+        For more information, see `Resource Tags`__.
+        Example: `{\"Department\": \"Finance\"}`
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm
+
+
+        :param freeform_tags: The freeform_tags of this Cluster.
+        :type: dict(str, str)
+        """
+        self._freeform_tags = freeform_tags
+
+    @property
+    def defined_tags(self):
+        """
+        Gets the defined_tags of this Cluster.
+        Defined tags for this resource. Each key is predefined and scoped to a namespace.
+        For more information, see `Resource Tags`__.
+        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm
+
+
+        :return: The defined_tags of this Cluster.
+        :rtype: dict(str, dict(str, object))
+        """
+        return self._defined_tags
+
+    @defined_tags.setter
+    def defined_tags(self, defined_tags):
+        """
+        Sets the defined_tags of this Cluster.
+        Defined tags for this resource. Each key is predefined and scoped to a namespace.
+        For more information, see `Resource Tags`__.
+        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm
+
+
+        :param defined_tags: The defined_tags of this Cluster.
+        :type: dict(str, dict(str, object))
+        """
+        self._defined_tags = defined_tags
+
+    @property
+    def system_tags(self):
+        """
+        Gets the system_tags of this Cluster.
+        Usage of system tag keys. These predefined keys are scoped to namespaces.
+        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
+
+
+        :return: The system_tags of this Cluster.
+        :rtype: dict(str, dict(str, object))
+        """
+        return self._system_tags
+
+    @system_tags.setter
+    def system_tags(self, system_tags):
+        """
+        Sets the system_tags of this Cluster.
+        Usage of system tag keys. These predefined keys are scoped to namespaces.
+        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
+
+
+        :param system_tags: The system_tags of this Cluster.
+        :type: dict(str, dict(str, object))
+        """
+        self._system_tags = system_tags
+
     @property
     def options(self):
         """
