@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from .launch_instance_platform_config import LaunchInstancePlatformConfig
@@ -10,8 +10,7 @@ from oci.decorators import init_model_state_from_kwargs
 @init_model_state_from_kwargs
 class AmdMilanBmLaunchInstancePlatformConfig(LaunchInstancePlatformConfig):
     """
-    The platform configuration used when launching a bare metal instance with an E4 shape
-    (the AMD Milan platform).
+    The platform configuration used when launching a bare metal instance with an E4 shape.
     """
 
     #: A constant which can be used with the numa_nodes_per_socket property of a AmdMilanBmLaunchInstancePlatformConfig.
