@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -108,6 +108,10 @@ class BootVolumeReplica(object):
             The value to assign to the total_data_transferred_in_gbs property of this BootVolumeReplica.
         :type total_data_transferred_in_gbs: int
 
+        :param volume_group_replica_id:
+            The value to assign to the volume_group_replica_id property of this BootVolumeReplica.
+        :type volume_group_replica_id: str
+
         """
         self.swagger_types = {
             'availability_domain': 'str',
@@ -122,7 +126,8 @@ class BootVolumeReplica(object):
             'time_last_synced': 'datetime',
             'boot_volume_id': 'str',
             'image_id': 'str',
-            'total_data_transferred_in_gbs': 'int'
+            'total_data_transferred_in_gbs': 'int',
+            'volume_group_replica_id': 'str'
         }
 
         self.attribute_map = {
@@ -138,7 +143,8 @@ class BootVolumeReplica(object):
             'time_last_synced': 'timeLastSynced',
             'boot_volume_id': 'bootVolumeId',
             'image_id': 'imageId',
-            'total_data_transferred_in_gbs': 'totalDataTransferredInGBs'
+            'total_data_transferred_in_gbs': 'totalDataTransferredInGBs',
+            'volume_group_replica_id': 'volumeGroupReplicaId'
         }
 
         self._availability_domain = None
@@ -154,6 +160,7 @@ class BootVolumeReplica(object):
         self._boot_volume_id = None
         self._image_id = None
         self._total_data_transferred_in_gbs = None
+        self._volume_group_replica_id = None
 
     @property
     def availability_domain(self):
@@ -511,6 +518,30 @@ class BootVolumeReplica(object):
         """
         self._total_data_transferred_in_gbs = total_data_transferred_in_gbs
 
+    @property
+    def volume_group_replica_id(self):
+        """
+        Gets the volume_group_replica_id of this BootVolumeReplica.
+        The OCID of the volume group replica.
+
+
+        :return: The volume_group_replica_id of this BootVolumeReplica.
+        :rtype: str
+        """
+        return self._volume_group_replica_id
+
+    @volume_group_replica_id.setter
+    def volume_group_replica_id(self, volume_group_replica_id):
+        """
+        Sets the volume_group_replica_id of this BootVolumeReplica.
+        The OCID of the volume group replica.
+
+
+        :param volume_group_replica_id: The volume_group_replica_id of this BootVolumeReplica.
+        :type: str
+        """
+        self._volume_group_replica_id = volume_group_replica_id
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
