@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -269,7 +269,9 @@ class Subnet(object):
     def compartment_id(self):
         """
         **[Required]** Gets the compartment_id of this Subnet.
-        The OCID of the compartment containing the subnet.
+        The `OCID`__ of the compartment containing the subnet.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :return: The compartment_id of this Subnet.
@@ -281,7 +283,9 @@ class Subnet(object):
     def compartment_id(self, compartment_id):
         """
         Sets the compartment_id of this Subnet.
-        The OCID of the compartment containing the subnet.
+        The `OCID`__ of the compartment containing the subnet.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :param compartment_id: The compartment_id of this Subnet.
@@ -327,7 +331,9 @@ class Subnet(object):
     def dhcp_options_id(self):
         """
         Gets the dhcp_options_id of this Subnet.
-        The OCID of the set of DHCP options that the subnet uses.
+        The `OCID`__ of the set of DHCP options that the subnet uses.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :return: The dhcp_options_id of this Subnet.
@@ -339,7 +345,9 @@ class Subnet(object):
     def dhcp_options_id(self, dhcp_options_id):
         """
         Sets the dhcp_options_id of this Subnet.
-        The OCID of the set of DHCP options that the subnet uses.
+        The `OCID`__ of the set of DHCP options that the subnet uses.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :param dhcp_options_id: The dhcp_options_id of this Subnet.
@@ -463,7 +471,9 @@ class Subnet(object):
     def id(self):
         """
         **[Required]** Gets the id of this Subnet.
-        The subnet's Oracle ID (OCID).
+        The subnet's Oracle ID (`OCID`__).
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :return: The id of this Subnet.
@@ -475,7 +485,9 @@ class Subnet(object):
     def id(self, id):
         """
         Sets the id of this Subnet.
-        The subnet's Oracle ID (OCID).
+        The subnet's Oracle ID (`OCID`__).
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :param id: The id of this Subnet.
@@ -671,7 +683,9 @@ class Subnet(object):
     def route_table_id(self):
         """
         **[Required]** Gets the route_table_id of this Subnet.
-        The OCID of the route table that the subnet uses.
+        The `OCID`__ of the route table that the subnet uses.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :return: The route_table_id of this Subnet.
@@ -683,7 +697,9 @@ class Subnet(object):
     def route_table_id(self, route_table_id):
         """
         Sets the route_table_id of this Subnet.
-        The OCID of the route table that the subnet uses.
+        The `OCID`__ of the route table that the subnet uses.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :param route_table_id: The route_table_id of this Subnet.
@@ -795,7 +811,9 @@ class Subnet(object):
     def vcn_id(self):
         """
         **[Required]** Gets the vcn_id of this Subnet.
-        The OCID of the VCN the subnet is in.
+        The `OCID`__ of the VCN the subnet is in.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :return: The vcn_id of this Subnet.
@@ -807,7 +825,9 @@ class Subnet(object):
     def vcn_id(self, vcn_id):
         """
         Sets the vcn_id of this Subnet.
-        The OCID of the VCN the subnet is in.
+        The `OCID`__ of the VCN the subnet is in.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
 
 
         :param vcn_id: The vcn_id of this Subnet.
