@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -90,6 +90,10 @@ class AttributeSummary(object):
             The value to assign to the length property of this AttributeSummary.
         :type length: int
 
+        :param position:
+            The value to assign to the position property of this AttributeSummary.
+        :type position: int
+
         :param precision:
             The value to assign to the precision property of this AttributeSummary.
         :type precision: int
@@ -120,6 +124,10 @@ class AttributeSummary(object):
             The value to assign to the external_data_type property of this AttributeSummary.
         :type external_data_type: str
 
+        :param type_key:
+            The value to assign to the type_key property of this AttributeSummary.
+        :type type_key: str
+
         :param min_collection_count:
             The value to assign to the min_collection_count property of this AttributeSummary.
         :type min_collection_count: int
@@ -166,6 +174,10 @@ class AttributeSummary(object):
             The value to assign to the time_updated property of this AttributeSummary.
         :type time_updated: datetime
 
+        :param properties:
+            The value to assign to the properties property of this AttributeSummary.
+        :type properties: dict(str, dict(str, str))
+
         """
         self.swagger_types = {
             'key': 'str',
@@ -175,6 +187,7 @@ class AttributeSummary(object):
             'entity_key': 'str',
             'external_key': 'str',
             'length': 'int',
+            'position': 'int',
             'precision': 'int',
             'scale': 'int',
             'is_nullable': 'bool',
@@ -182,6 +195,7 @@ class AttributeSummary(object):
             'lifecycle_state': 'str',
             'time_created': 'datetime',
             'external_data_type': 'str',
+            'type_key': 'str',
             'min_collection_count': 'int',
             'max_collection_count': 'int',
             'datatype_entity_key': 'str',
@@ -192,7 +206,8 @@ class AttributeSummary(object):
             'custom_property_members': 'list[CustomPropertyGetUsage]',
             'associated_rule_types': 'list[str]',
             'is_derived_attribute': 'bool',
-            'time_updated': 'datetime'
+            'time_updated': 'datetime',
+            'properties': 'dict(str, dict(str, str))'
         }
 
         self.attribute_map = {
@@ -203,6 +218,7 @@ class AttributeSummary(object):
             'entity_key': 'entityKey',
             'external_key': 'externalKey',
             'length': 'length',
+            'position': 'position',
             'precision': 'precision',
             'scale': 'scale',
             'is_nullable': 'isNullable',
@@ -210,6 +226,7 @@ class AttributeSummary(object):
             'lifecycle_state': 'lifecycleState',
             'time_created': 'timeCreated',
             'external_data_type': 'externalDataType',
+            'type_key': 'typeKey',
             'min_collection_count': 'minCollectionCount',
             'max_collection_count': 'maxCollectionCount',
             'datatype_entity_key': 'datatypeEntityKey',
@@ -220,7 +237,8 @@ class AttributeSummary(object):
             'custom_property_members': 'customPropertyMembers',
             'associated_rule_types': 'associatedRuleTypes',
             'is_derived_attribute': 'isDerivedAttribute',
-            'time_updated': 'timeUpdated'
+            'time_updated': 'timeUpdated',
+            'properties': 'properties'
         }
 
         self._key = None
@@ -230,6 +248,7 @@ class AttributeSummary(object):
         self._entity_key = None
         self._external_key = None
         self._length = None
+        self._position = None
         self._precision = None
         self._scale = None
         self._is_nullable = None
@@ -237,6 +256,7 @@ class AttributeSummary(object):
         self._lifecycle_state = None
         self._time_created = None
         self._external_data_type = None
+        self._type_key = None
         self._min_collection_count = None
         self._max_collection_count = None
         self._datatype_entity_key = None
@@ -248,6 +268,7 @@ class AttributeSummary(object):
         self._associated_rule_types = None
         self._is_derived_attribute = None
         self._time_updated = None
+        self._properties = None
 
     @property
     def key(self):
@@ -419,6 +440,30 @@ class AttributeSummary(object):
         """
         self._length = length
 
+    @property
+    def position(self):
+        """
+        Gets the position of this AttributeSummary.
+        Position of the attribute in the record definition.
+
+
+        :return: The position of this AttributeSummary.
+        :rtype: int
+        """
+        return self._position
+
+    @position.setter
+    def position(self, position):
+        """
+        Sets the position of this AttributeSummary.
+        Position of the attribute in the record definition.
+
+
+        :param position: The position of this AttributeSummary.
+        :type: int
+        """
+        self._position = position
+
     @property
     def precision(self):
         """
@@ -599,6 +644,30 @@ class AttributeSummary(object):
         """
         self._external_data_type = external_data_type
 
+    @property
+    def type_key(self):
+        """
+        Gets the type_key of this AttributeSummary.
+        The type of the attribute. Type keys can be found via the '/types' endpoint.
+
+
+        :return: The type_key of this AttributeSummary.
+        :rtype: str
+        """
+        return self._type_key
+
+    @type_key.setter
+    def type_key(self, type_key):
+        """
+        Sets the type_key of this AttributeSummary.
+        The type of the attribute. Type keys can be found via the '/types' endpoint.
+
+
+        :param type_key: The type_key of this AttributeSummary.
+        :type: str
+        """
+        self._type_key = type_key
+
     @property
     def min_collection_count(self):
         """
@@ -877,6 +946,38 @@ class AttributeSummary(object):
         """
         self._time_updated = time_updated
 
+    @property
+    def properties(self):
+        """
+        Gets the properties of this AttributeSummary.
+        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
+        definition defines it's set of required and optional properties. The map keys are category names and the
+        values are maps of property name to property value. Every property is contained inside of a category. Most
+        attributes have required properties within the \"default\" category.
+        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`
+
+
+        :return: The properties of this AttributeSummary.
+        :rtype: dict(str, dict(str, str))
+        """
+        return self._properties
+
+    @properties.setter
+    def properties(self, properties):
+        """
+        Sets the properties of this AttributeSummary.
+        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
+        definition defines it's set of required and optional properties. The map keys are category names and the
+        values are maps of property name to property value. Every property is contained inside of a category. Most
+        attributes have required properties within the \"default\" category.
+        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`
+
+
+        :param properties: The properties of this AttributeSummary.
+        :type: dict(str, dict(str, str))
+        """
+        self._properties = properties
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
