@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -146,6 +146,10 @@ class AutonomousContainerDatabase(object):
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type infrastructure_type: str
 
+        :param cloud_autonomous_vm_cluster_id:
+            The value to assign to the cloud_autonomous_vm_cluster_id property of this AutonomousContainerDatabase.
+        :type cloud_autonomous_vm_cluster_id: str
+
         :param kms_key_id:
             The value to assign to the kms_key_id property of this AutonomousContainerDatabase.
         :type kms_key_id: str
@@ -154,6 +158,14 @@ class AutonomousContainerDatabase(object):
             The value to assign to the vault_id property of this AutonomousContainerDatabase.
         :type vault_id: str
 
+        :param kms_key_version_id:
+            The value to assign to the kms_key_version_id property of this AutonomousContainerDatabase.
+        :type kms_key_version_id: str
+
+        :param key_history_entry:
+            The value to assign to the key_history_entry property of this AutonomousContainerDatabase.
+        :type key_history_entry: list[oci.database.models.AutonomousDatabaseKeyHistoryEntry]
+
         :param lifecycle_state:
             The value to assign to the lifecycle_state property of this AutonomousContainerDatabase.
             Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "BACKUP_IN_PROGRESS", "RESTORING", "RESTORE_FAILED", "RESTARTING", "MAINTENANCE_IN_PROGRESS", "ROLE_CHANGE_IN_PROGRESS", "UNAVAILABLE", 'UNKNOWN_ENUM_VALUE'.
@@ -238,8 +250,11 @@ class AutonomousContainerDatabase(object):
             'autonomous_exadata_infrastructure_id': 'str',
             'autonomous_vm_cluster_id': 'str',
             'infrastructure_type': 'str',
+            'cloud_autonomous_vm_cluster_id': 'str',
             'kms_key_id': 'str',
             'vault_id': 'str',
+            'kms_key_version_id': 'str',
+            'key_history_entry': 'list[AutonomousDatabaseKeyHistoryEntry]',
             'lifecycle_state': 'str',
             'lifecycle_details': 'str',
             'time_created': 'datetime',
@@ -268,8 +283,11 @@ class AutonomousContainerDatabase(object):
             'autonomous_exadata_infrastructure_id': 'autonomousExadataInfrastructureId',
             'autonomous_vm_cluster_id': 'autonomousVmClusterId',
             'infrastructure_type': 'infrastructureType',
+            'cloud_autonomous_vm_cluster_id': 'cloudAutonomousVmClusterId',
             'kms_key_id': 'kmsKeyId',
             'vault_id': 'vaultId',
+            'kms_key_version_id': 'kmsKeyVersionId',
+            'key_history_entry': 'keyHistoryEntry',
             'lifecycle_state': 'lifecycleState',
             'lifecycle_details': 'lifecycleDetails',
             'time_created': 'timeCreated',
@@ -297,8 +315,11 @@ class AutonomousContainerDatabase(object):
         self._autonomous_exadata_infrastructure_id = None
         self._autonomous_vm_cluster_id = None
         self._infrastructure_type = None
+        self._cloud_autonomous_vm_cluster_id = None
         self._kms_key_id = None
         self._vault_id = None
+        self._kms_key_version_id = None
+        self._key_history_entry = None
         self._lifecycle_state = None
         self._lifecycle_details = None
         self._time_created = None
@@ -393,7 +414,7 @@ class AutonomousContainerDatabase(object):
     def db_unique_name(self):
         """
         Gets the db_unique_name of this AutonomousContainerDatabase.
-        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.
+        **Deprecated.** The `DB_UNIQUE_NAME` value is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :return: The db_unique_name of this AutonomousContainerDatabase.
@@ -405,7 +426,7 @@ class AutonomousContainerDatabase(object):
     def db_unique_name(self, db_unique_name):
         """
         Sets the db_unique_name of this AutonomousContainerDatabase.
-        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.
+        **Deprecated.** The `DB_UNIQUE_NAME` value is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :param db_unique_name: The db_unique_name of this AutonomousContainerDatabase.
@@ -521,6 +542,34 @@ class AutonomousContainerDatabase(object):
             infrastructure_type = 'UNKNOWN_ENUM_VALUE'
         self._infrastructure_type = infrastructure_type
 
+    @property
+    def cloud_autonomous_vm_cluster_id(self):
+        """
+        Gets the cloud_autonomous_vm_cluster_id of this AutonomousContainerDatabase.
+        The `OCID`__ of the cloud Autonomous Exadata VM Cluster.
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
+
+
+        :return: The cloud_autonomous_vm_cluster_id of this AutonomousContainerDatabase.
+        :rtype: str
+        """
+        return self._cloud_autonomous_vm_cluster_id
+
+    @cloud_autonomous_vm_cluster_id.setter
+    def cloud_autonomous_vm_cluster_id(self, cloud_autonomous_vm_cluster_id):
+        """
+        Sets the cloud_autonomous_vm_cluster_id of this AutonomousContainerDatabase.
+        The `OCID`__ of the cloud Autonomous Exadata VM Cluster.
+
+        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
+
+
+        :param cloud_autonomous_vm_cluster_id: The cloud_autonomous_vm_cluster_id of this AutonomousContainerDatabase.
+        :type: str
+        """
+        self._cloud_autonomous_vm_cluster_id = cloud_autonomous_vm_cluster_id
+
     @property
     def kms_key_id(self):
         """
@@ -575,6 +624,54 @@ class AutonomousContainerDatabase(object):
         """
         self._vault_id = vault_id
 
+    @property
+    def kms_key_version_id(self):
+        """
+        Gets the kms_key_version_id of this AutonomousContainerDatabase.
+        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
+
+
+        :return: The kms_key_version_id of this AutonomousContainerDatabase.
+        :rtype: str
+        """
+        return self._kms_key_version_id
+
+    @kms_key_version_id.setter
+    def kms_key_version_id(self, kms_key_version_id):
+        """
+        Sets the kms_key_version_id of this AutonomousContainerDatabase.
+        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
+
+
+        :param kms_key_version_id: The kms_key_version_id of this AutonomousContainerDatabase.
+        :type: str
+        """
+        self._kms_key_version_id = kms_key_version_id
+
+    @property
+    def key_history_entry(self):
+        """
+        Gets the key_history_entry of this AutonomousContainerDatabase.
+        Key History Entry.
+
+
+        :return: The key_history_entry of this AutonomousContainerDatabase.
+        :rtype: list[oci.database.models.AutonomousDatabaseKeyHistoryEntry]
+        """
+        return self._key_history_entry
+
+    @key_history_entry.setter
+    def key_history_entry(self, key_history_entry):
+        """
+        Sets the key_history_entry of this AutonomousContainerDatabase.
+        Key History Entry.
+
+
+        :param key_history_entry: The key_history_entry of this AutonomousContainerDatabase.
+        :type: list[oci.database.models.AutonomousDatabaseKeyHistoryEntry]
+        """
+        self._key_history_entry = key_history_entry
+
     @property
     def lifecycle_state(self):
         """
