@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -172,6 +172,10 @@ class DataGuardAssociationSummary(object):
             The value to assign to the time_created property of this DataGuardAssociationSummary.
         :type time_created: datetime
 
+        :param is_active_data_guard_enabled:
+            The value to assign to the is_active_data_guard_enabled property of this DataGuardAssociationSummary.
+        :type is_active_data_guard_enabled: bool
+
         """
         self.swagger_types = {
             'id': 'str',
@@ -188,7 +192,8 @@ class DataGuardAssociationSummary(object):
             'apply_rate': 'str',
             'protection_mode': 'str',
             'transport_type': 'str',
-            'time_created': 'datetime'
+            'time_created': 'datetime',
+            'is_active_data_guard_enabled': 'bool'
         }
 
         self.attribute_map = {
@@ -206,7 +211,8 @@ class DataGuardAssociationSummary(object):
             'apply_rate': 'applyRate',
             'protection_mode': 'protectionMode',
             'transport_type': 'transportType',
-            'time_created': 'timeCreated'
+            'time_created': 'timeCreated',
+            'is_active_data_guard_enabled': 'isActiveDataGuardEnabled'
         }
 
         self._id = None
@@ -224,6 +230,7 @@ class DataGuardAssociationSummary(object):
         self._protection_mode = None
         self._transport_type = None
         self._time_created = None
+        self._is_active_data_guard_enabled = None
 
     @property
     def id(self):
@@ -667,6 +674,30 @@ class DataGuardAssociationSummary(object):
         """
         self._time_created = time_created
 
+    @property
+    def is_active_data_guard_enabled(self):
+        """
+        Gets the is_active_data_guard_enabled of this DataGuardAssociationSummary.
+        True if active Data Guard is enabled.
+
+
+        :return: The is_active_data_guard_enabled of this DataGuardAssociationSummary.
+        :rtype: bool
+        """
+        return self._is_active_data_guard_enabled
+
+    @is_active_data_guard_enabled.setter
+    def is_active_data_guard_enabled(self, is_active_data_guard_enabled):
+        """
+        Sets the is_active_data_guard_enabled of this DataGuardAssociationSummary.
+        True if active Data Guard is enabled.
+
+
+        :param is_active_data_guard_enabled: The is_active_data_guard_enabled of this DataGuardAssociationSummary.
+        :type: bool
+        """
+        self._is_active_data_guard_enabled = is_active_data_guard_enabled
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
