@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -25,10 +25,22 @@ class Job(object):
     #: This constant has a value of "NON_CDB"
     DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"
 
+    #: A constant which can be used with the database_sub_type property of a Job.
+    #: This constant has a value of "ACD"
+    DATABASE_SUB_TYPE_ACD = "ACD"
+
+    #: A constant which can be used with the database_sub_type property of a Job.
+    #: This constant has a value of "ADB"
+    DATABASE_SUB_TYPE_ADB = "ADB"
+
     #: A constant which can be used with the schedule_type property of a Job.
     #: This constant has a value of "IMMEDIATE"
     SCHEDULE_TYPE_IMMEDIATE = "IMMEDIATE"
 
+    #: A constant which can be used with the schedule_type property of a Job.
+    #: This constant has a value of "LATER"
+    SCHEDULE_TYPE_LATER = "LATER"
+
     #: A constant which can be used with the job_type property of a Job.
     #: This constant has a value of "SQL"
     JOB_TYPE_SQL = "SQL"
@@ -80,13 +92,13 @@ class Job(object):
 
         :param database_sub_type:
             The value to assign to the database_sub_type property of this Job.
-            Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type database_sub_type: str
 
         :param schedule_type:
             The value to assign to the schedule_type property of this Job.
-            Allowed values for this property are: "IMMEDIATE", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "IMMEDIATE", "LATER", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type schedule_type: str
 
@@ -110,6 +122,10 @@ class Job(object):
             The value to assign to the result_location property of this Job.
         :type result_location: oci.database_management.models.JobExecutionResultLocation
 
+        :param schedule_details:
+            The value to assign to the schedule_details property of this Job.
+        :type schedule_details: oci.database_management.models.JobScheduleDetails
+
         :param submission_error_message:
             The value to assign to the submission_error_message property of this Job.
         :type submission_error_message: str
@@ -137,6 +153,7 @@ class Job(object):
             'lifecycle_state': 'str',
             'timeout': 'str',
             'result_location': 'JobExecutionResultLocation',
+            'schedule_details': 'JobScheduleDetails',
             'submission_error_message': 'str',
             'time_created': 'datetime',
             'time_updated': 'datetime'
@@ -156,6 +173,7 @@ class Job(object):
             'lifecycle_state': 'lifecycleState',
             'timeout': 'timeout',
             'result_location': 'resultLocation',
+            'schedule_details': 'scheduleDetails',
             'submission_error_message': 'submissionErrorMessage',
             'time_created': 'timeCreated',
             'time_updated': 'timeUpdated'
@@ -174,6 +192,7 @@ class Job(object):
         self._lifecycle_state = None
         self._timeout = None
         self._result_location = None
+        self._schedule_details = None
         self._submission_error_message = None
         self._time_created = None
         self._time_updated = None
@@ -381,7 +400,7 @@ class Job(object):
         Gets the database_sub_type of this Job.
         The subtype of the Oracle Database where the job has to be executed. Applicable only when managedDatabaseGroupId is provided.
 
-        Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -400,7 +419,7 @@ class Job(object):
         :param database_sub_type: The database_sub_type of this Job.
         :type: str
         """
-        allowed_values = ["CDB", "PDB", "NON_CDB"]
+        allowed_values = ["CDB", "PDB", "NON_CDB", "ACD", "ADB"]
         if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
             database_sub_type = 'UNKNOWN_ENUM_VALUE'
         self._database_sub_type = database_sub_type
@@ -411,7 +430,7 @@ class Job(object):
         **[Required]** Gets the schedule_type of this Job.
         The schedule type of the job.
 
-        Allowed values for this property are: "IMMEDIATE", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "IMMEDIATE", "LATER", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -430,7 +449,7 @@ class Job(object):
         :param schedule_type: The schedule_type of this Job.
         :type: str
         """
-        allowed_values = ["IMMEDIATE"]
+        allowed_values = ["IMMEDIATE", "LATER"]
         if not value_allowed_none_or_none_sentinel(schedule_type, allowed_values):
             schedule_type = 'UNKNOWN_ENUM_VALUE'
         self._schedule_type = schedule_type
@@ -539,6 +558,26 @@ class Job(object):
         """
         self._result_location = result_location
 
+    @property
+    def schedule_details(self):
+        """
+        Gets the schedule_details of this Job.
+
+        :return: The schedule_details of this Job.
+        :rtype: oci.database_management.models.JobScheduleDetails
+        """
+        return self._schedule_details
+
+    @schedule_details.setter
+    def schedule_details(self, schedule_details):
+        """
+        Sets the schedule_details of this Job.
+
+        :param schedule_details: The schedule_details of this Job.
+        :type: oci.database_management.models.JobScheduleDetails
+        """
+        self._schedule_details = schedule_details
+
     @property
     def submission_error_message(self):
         """
