@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -29,6 +29,14 @@ class JobExecution(object):
     #: This constant has a value of "CLOUD_RAC"
     DATABASE_TYPE_CLOUD_RAC = "CLOUD_RAC"
 
+    #: A constant which can be used with the database_type property of a JobExecution.
+    #: This constant has a value of "SHARED"
+    DATABASE_TYPE_SHARED = "SHARED"
+
+    #: A constant which can be used with the database_type property of a JobExecution.
+    #: This constant has a value of "DEDICATED"
+    DATABASE_TYPE_DEDICATED = "DEDICATED"
+
     #: A constant which can be used with the database_sub_type property of a JobExecution.
     #: This constant has a value of "CDB"
     DATABASE_SUB_TYPE_CDB = "CDB"
@@ -41,6 +49,14 @@ class JobExecution(object):
     #: This constant has a value of "NON_CDB"
     DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"
 
+    #: A constant which can be used with the database_sub_type property of a JobExecution.
+    #: This constant has a value of "ACD"
+    DATABASE_SUB_TYPE_ACD = "ACD"
+
+    #: A constant which can be used with the database_sub_type property of a JobExecution.
+    #: This constant has a value of "ADB"
+    DATABASE_SUB_TYPE_ADB = "ADB"
+
     #: A constant which can be used with the deployment_type property of a JobExecution.
     #: This constant has a value of "ONPREMISE"
     DEPLOYMENT_TYPE_ONPREMISE = "ONPREMISE"
@@ -61,6 +77,26 @@ class JobExecution(object):
     #: This constant has a value of "EXADATA_CC"
     DEPLOYMENT_TYPE_EXADATA_CC = "EXADATA_CC"
 
+    #: A constant which can be used with the deployment_type property of a JobExecution.
+    #: This constant has a value of "AUTONOMOUS"
+    DEPLOYMENT_TYPE_AUTONOMOUS = "AUTONOMOUS"
+
+    #: A constant which can be used with the workload_type property of a JobExecution.
+    #: This constant has a value of "OLTP"
+    WORKLOAD_TYPE_OLTP = "OLTP"
+
+    #: A constant which can be used with the workload_type property of a JobExecution.
+    #: This constant has a value of "DW"
+    WORKLOAD_TYPE_DW = "DW"
+
+    #: A constant which can be used with the workload_type property of a JobExecution.
+    #: This constant has a value of "AJD"
+    WORKLOAD_TYPE_AJD = "AJD"
+
+    #: A constant which can be used with the workload_type property of a JobExecution.
+    #: This constant has a value of "APEX"
+    WORKLOAD_TYPE_APEX = "APEX"
+
     #: A constant which can be used with the status property of a JobExecution.
     #: This constant has a value of "SUCCEEDED"
     STATUS_SUCCEEDED = "SUCCEEDED"
@@ -104,19 +140,19 @@ class JobExecution(object):
 
         :param database_type:
             The value to assign to the database_type property of this JobExecution.
-            Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type database_type: str
 
         :param database_sub_type:
             The value to assign to the database_sub_type property of this JobExecution.
-            Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type database_sub_type: str
 
         :param deployment_type:
             The value to assign to the deployment_type property of this JobExecution.
-            Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", 'UNKNOWN_ENUM_VALUE'.
+            Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
             Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type deployment_type: str
 
@@ -124,6 +160,12 @@ class JobExecution(object):
             The value to assign to the is_cluster property of this JobExecution.
         :type is_cluster: bool
 
+        :param workload_type:
+            The value to assign to the workload_type property of this JobExecution.
+            Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
+            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
+        :type workload_type: str
+
         :param job_id:
             The value to assign to the job_id property of this JobExecution.
         :type job_id: str
@@ -182,6 +224,7 @@ class JobExecution(object):
             'database_sub_type': 'str',
             'deployment_type': 'str',
             'is_cluster': 'bool',
+            'workload_type': 'str',
             'job_id': 'str',
             'job_name': 'str',
             'job_run_id': 'str',
@@ -206,6 +249,7 @@ class JobExecution(object):
             'database_sub_type': 'databaseSubType',
             'deployment_type': 'deploymentType',
             'is_cluster': 'isCluster',
+            'workload_type': 'workloadType',
             'job_id': 'jobId',
             'job_name': 'jobName',
             'job_run_id': 'jobRunId',
@@ -229,6 +273,7 @@ class JobExecution(object):
         self._database_sub_type = None
         self._deployment_type = None
         self._is_cluster = None
+        self._workload_type = None
         self._job_id = None
         self._job_name = None
         self._job_run_id = None
@@ -403,7 +448,7 @@ class JobExecution(object):
         Gets the database_type of this JobExecution.
         The type of Oracle Database installation.
 
-        Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -422,7 +467,7 @@ class JobExecution(object):
         :param database_type: The database_type of this JobExecution.
         :type: str
         """
-        allowed_values = ["EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC"]
+        allowed_values = ["EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", "SHARED", "DEDICATED"]
         if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
             database_type = 'UNKNOWN_ENUM_VALUE'
         self._database_type = database_type
@@ -433,7 +478,7 @@ class JobExecution(object):
         Gets the database_sub_type of this JobExecution.
         The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
 
-        Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "CDB", "PDB", "NON_CDB", "ACD", "ADB", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -452,7 +497,7 @@ class JobExecution(object):
         :param database_sub_type: The database_sub_type of this JobExecution.
         :type: str
         """
-        allowed_values = ["CDB", "PDB", "NON_CDB"]
+        allowed_values = ["CDB", "PDB", "NON_CDB", "ACD", "ADB"]
         if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
             database_sub_type = 'UNKNOWN_ENUM_VALUE'
         self._database_sub_type = database_sub_type
@@ -463,7 +508,7 @@ class JobExecution(object):
         Gets the deployment_type of this JobExecution.
         A list of the supported infrastructure that can be used to deploy the database.
 
-        Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", 'UNKNOWN_ENUM_VALUE'.
+        Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS", 'UNKNOWN_ENUM_VALUE'.
         Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
@@ -482,7 +527,7 @@ class JobExecution(object):
         :param deployment_type: The deployment_type of this JobExecution.
         :type: str
         """
-        allowed_values = ["ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC"]
+        allowed_values = ["ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", "AUTONOMOUS"]
         if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
             deployment_type = 'UNKNOWN_ENUM_VALUE'
         self._deployment_type = deployment_type
@@ -511,6 +556,36 @@ class JobExecution(object):
         """
         self._is_cluster = is_cluster
 
+    @property
+    def workload_type(self):
+        """
+        Gets the workload_type of this JobExecution.
+        The workload type of the Autonomous Database.
+
+        Allowed values for this property are: "OLTP", "DW", "AJD", "APEX", 'UNKNOWN_ENUM_VALUE'.
+        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
+
+
+        :return: The workload_type of this JobExecution.
+        :rtype: str
+        """
+        return self._workload_type
+
+    @workload_type.setter
+    def workload_type(self, workload_type):
+        """
+        Sets the workload_type of this JobExecution.
+        The workload type of the Autonomous Database.
+
+
+        :param workload_type: The workload_type of this JobExecution.
+        :type: str
+        """
+        allowed_values = ["OLTP", "DW", "AJD", "APEX"]
+        if not value_allowed_none_or_none_sentinel(workload_type, allowed_values):
+            workload_type = 'UNKNOWN_ENUM_VALUE'
+        self._workload_type = workload_type
+
     @property
     def job_id(self):
         """
