@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -143,6 +143,10 @@ class TestParserPayloadDetails(object):
             Allowed values for this property are: "XML", "JSON", "REGEX", "ODL", "DELIMITED"
         :type type: str
 
+        :param is_namespace_aware:
+            The value to assign to the is_namespace_aware property of this TestParserPayloadDetails.
+        :type is_namespace_aware: bool
+
         """
         self.swagger_types = {
             'content': 'str',
@@ -170,7 +174,8 @@ class TestParserPayloadDetails(object):
             'should_tokenize_original_text': 'bool',
             'field_delimiter': 'str',
             'field_qualifier': 'str',
-            'type': 'str'
+            'type': 'str',
+            'is_namespace_aware': 'bool'
         }
 
         self.attribute_map = {
@@ -199,7 +204,8 @@ class TestParserPayloadDetails(object):
             'should_tokenize_original_text': 'shouldTokenizeOriginalText',
             'field_delimiter': 'fieldDelimiter',
             'field_qualifier': 'fieldQualifier',
-            'type': 'type'
+            'type': 'type',
+            'is_namespace_aware': 'isNamespaceAware'
         }
 
         self._content = None
@@ -228,6 +234,7 @@ class TestParserPayloadDetails(object):
         self._field_delimiter = None
         self._field_qualifier = None
         self._type = None
+        self._is_namespace_aware = None
 
     @property
     def content(self):
@@ -859,6 +866,30 @@ class TestParserPayloadDetails(object):
             )
         self._type = type
 
+    @property
+    def is_namespace_aware(self):
+        """
+        Gets the is_namespace_aware of this TestParserPayloadDetails.
+        A flag indicating whether the XML parser should consider the namespace(s) while processing the log data.
+
+
+        :return: The is_namespace_aware of this TestParserPayloadDetails.
+        :rtype: bool
+        """
+        return self._is_namespace_aware
+
+    @is_namespace_aware.setter
+    def is_namespace_aware(self, is_namespace_aware):
+        """
+        Sets the is_namespace_aware of this TestParserPayloadDetails.
+        A flag indicating whether the XML parser should consider the namespace(s) while processing the log data.
+
+
+        :param is_namespace_aware: The is_namespace_aware of this TestParserPayloadDetails.
+        :type: bool
+        """
+        self._is_namespace_aware = is_namespace_aware
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
